import { ICellRendererComp, ICellRendererParams } from '@ag-grid-community/core';
import { FoundationElement } from '@microsoft/fast-foundation';
/**
 * Parameters for the {@link @genesislcap/grid-pro#GridPro} boolean renderer.
 * @public
 */
export type BooleanRendererParams = {
    /**
     * Function to determine whether the boolean renderer should be disabled for a specific row.
     * @param rowData - The data associated with the row.
     * @returns A boolean indicating whether the button should be disabled.
     */
    isDisabled?: (rowData: any) => boolean;
};
/**
 * The AG Boolean Renderer element.
 * @public
 * @tagname %%prefix%%-boolean-renderer
 */
export declare class BooleanRenderer extends FoundationElement implements ICellRendererComp {
    params: ICellRendererParams & BooleanRendererParams;
    selected: boolean;
    isDisabled(data: any): boolean;
    init(params: ICellRendererParams): void;
    changeHandler(e: any): void;
    getGui(): HTMLElement;
    destroy(): void;
    refresh(params: ICellRendererParams): boolean;
    getValue(): boolean;
    isCancelBeforeStart(): boolean;
}
/**
 * The AG Boolean Renderer Styles.
 * @public
 */
export declare const agBooleanRendererStyles: import("@microsoft/fast-element").ElementStyles;
/**
 * Get a Design System prefixed Checkbox template.
 * @param designSystem - The design system prefix to use. Defaults to 'foundation'.
 * @returns A Checkbox component template prefixed with the correct design system.
 * @public
 */
export declare const getAgBooleanRendererTemplate: (designSystem?: string) => import("@microsoft/fast-element").ViewTemplate<BooleanRenderer, any>;
/**
 * A function that returns a Foundation Boolean Renderer registration for configuring the component with a DesignSystem.
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-boolean-renderer\>
 */
export declare const foundationAgBooleanRenderer: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    styles: import("@microsoft/fast-element").ElementStyles;
    template: import("@microsoft/fast-element").ViewTemplate<BooleanRenderer, any>;
}>) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    styles: import("@microsoft/fast-element").ElementStyles;
    template: import("@microsoft/fast-element").ViewTemplate<BooleanRenderer, any>;
}, typeof BooleanRenderer>;
//# sourceMappingURL=boolean.renderer.d.ts.map